@@ -38,6 +38,20 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 				Value: string(masterKey),
 			},
 		}
+	} else {
+		// support Rails 4 through 5.1 applications, or ones that started out
+		// there and never were fully upgraded.
+		out, err := exec.Command("rake", "secret").Output()
+
+		if err == nil {
+			s.Secrets = []Secret{
+				{
+					Key:   "SECRET_KEY_BASE",
+					Help:  "Secret key used to verify the integrity of signed cookies",
+					Value: strings.TrimSpace(string(out)),
+				},
+			}
+		}
 	}
 
 	s.SkipDeploy = true
@@ -60,7 +74,7 @@ func RailsCallback(srcInfo *SourceInfo, options map[string]bool) error {
 		panic(err)
 	} else if !strings.Contains(string(gemfile), "dockerfile-rails") {
 		cmd := exec.Command("bundle", "add", "dockerfile-rails",
-			"--version", ">= 1.0.0", "--group", "development")
+			"--optimistic", "--group", "development", "--skip-install")
 		cmd.Stdin = nil
 		cmd.Stdout = os.Stdout
 		cmd.Stderr = os.Stderr
@@ -68,12 +82,22 @@ func RailsCallback(srcInfo *SourceInfo, options map[string]bool) error {
 		if err := cmd.Run(); err != nil {
 			return errors.Wrap(err, "Failed to add dockerfile-rails gem, exiting")
 		}
+
+		cmd = exec.Command("bundle", "install", "--quiet")
+		cmd.Stdin = nil
+		cmd.Stdout = os.Stdout
+		cmd.Stderr = os.Stderr
+
+		if err := cmd.Run(); err != nil {
+			return errors.Wrap(err, "Failed to install dockerfile-rails gem, exiting")
+		}
 	}
 
 	// generate Dockerfile if it doesn't already exist
 	_, err = os.Stat("Dockerfile")
 	if errors.Is(err, fs.ErrNotExist) {
-		args := []string{"./bin/rails", "generate", "dockerfile"}
+		args := []string{"./bin/rails", "generate", "dockerfile",
+			"--label=fly_launch_runtime:rails"}
 
 		if options["postgresql"] {
 			args = append(args, "--postgresql")
